@@ -123,5 +123,10 @@
 # undef BSON_HAVE_SYSCALL_TID
 #endif
 
+#define BSON_HAVE_RAND_R 1
+#if BSON_HAVE_RAND_R != 1
+# undef BSON_HAVE_RAND_R
+#endif
+
 
 #endif /* BSON_CONFIG_H */
